@@ -1,6 +1,7 @@
 from .magichue import Light
+from .modes import *
 
 
 __author__ = 'namacha'
-__version__ = 0.1
+__version__ = '0.2.7'
 __license__ = 'MIT'
